@@ -260,8 +260,8 @@ def upload_bag(rosbag_file_name, source):
 @click.argument('topics_file', type=click.Path(exists=True))
 @click.argument('rosbag_file_name')
 @click.argument('source')
-@click.option('--delete_rosbag', is_flag=True, default=True, help='Keep the rosbag file after recording')
-def record_rosbag(topics_file, rosbag_file_name, source, delete_rosbag):
+@click.option('--keep_rosbag', is_flag=True, default=False, help='Keep the rosbag file after recording')
+def record_rosbag(topics_file, rosbag_file_name, source, keep_rosbag):
 
     with open(topics_file) as f:
         topics = [line.strip() for line in f.readlines()]
@@ -290,17 +290,27 @@ def record_rosbag(topics_file, rosbag_file_name, source, delete_rosbag):
 
         time.sleep(2)
 
-        # check connection
-        net = "IllinoisNet"
-        while(subprocess.check_output("iwgetid -r", shell=True).decode().strip() != net):
-            print("Not connected to IllinoisNet. Retrying in 1 second")
-            time.sleep(1)
+        while (True):
+            try: 
+                response = requests.get(f"{base_url}")
+                if response.status_code == 404:
+                    break
+            except requests.ConnectionError:
+                print("No internet connection")
+            except requests.Timeout:
+                print("Request timed out")
+            except requests.RequestException as e:
+                print(f"An error occurred: {e}")
+            
+            print("Please check your internet connection")
+            print("Retrying in 5 seconds")
+            time.sleep(5)
 
         # send rosbag file through api
         print("Uploading rosbag file")
         upload_bag(path, source)
        
-        if delete_rosbag:
+        if not keep_rosbag:
             print("Removing rosbag file")
             subprocess.run(f"rm {rosbag_file_name}", shell=True)
         exit(0)
